@@ -1,4 +1,4 @@
-/* $Id: bwbar.c,v 1.3 2001/05/05 22:51:48 hpa Exp $ */
+/* $Id: bwbar.c,v 1.5 2001/09/21 22:33:35 hpa Exp $ */
 /* ----------------------------------------------------------------------- *
  *   
  *   Copyright 1999-2001 H. Peter Anvin - All Rights Reserved
@@ -153,6 +153,9 @@ const struct option longopts[] = {
   { "width",        1, 0, 'x' },
   { "height",       1, 0, 'y' },
   { "border",       1, 0, 'b' },
+  { "kbps",         0, 0, 'k' },
+  { "Mbps",         0, 0, 'M' },
+  { "Gbps",         0, 0, 'G' },
   { "help",         0, 0, 'h' },
   { 0, 0, 0, 0 }
 };
@@ -167,11 +170,15 @@ void usage(int err)
 	  "   --input               -i   Measure input bandwidth\n"
 	  "   --output              -o   Measure output bandwidth (default)\n"
 	  "   --text-file <file>    -f   The name of the text output file (ubar.txt)\n"
-	  "   --png-file <file>     -g   The name of the graphical bar file (ubar.png)\n"
+	  "   --png-file <file>     -p   The name of the graphical bar file (ubar.png)\n"
 	  "   --interval <seconds>  -t   The poll interval in seconds (15)\n"
 	  "   --width <pixels>      -x   Width of the graphical bar (600)\n"
 	  "   --height <pixels>     -y   Height of the graphical bar (4)\n"
-	  "   --border <pixels>     -b   Border width of the graphical bar (1)\n",
+	  "   --border <pixels>     -b   Border width of the graphical bar (1)\n"
+	  "   --kbps                -k   Bandwidth is measured in kbit/s\n"
+	  "   --Mbps                -M   Bandwidth is measured in Mbit/s (default)\n"
+	  "   --Gbps                -G   Bandwidth is measured in Gbit/s\n"
+	  "   --help                -h   Display this text\n",
 	  program);
   exit(err);
 }
@@ -198,6 +205,8 @@ int main(int argc, char *argv[])
   int measure_input = 0;	/* Input instead of output */
   char *text_file = "ubar.txt";	/* Text filename */
   char *graphics_file = "ubar.png"; /* Graphics filename */
+  char *unit_name = "Mbit/s";	/* Unit name */
+  double unit = 1.0e+6;		/* Unit multiplier */
   int interval = 15;		/* Interval between measurements (s) */
   int width = 600;		/* Bar width */
   int height = 4;		/* Bar height */
@@ -205,7 +214,7 @@ int main(int argc, char *argv[])
 
   program = argv[0];
 
-  while ( (opt = getopt_long(argc, argv, "iof:p:t:x:y:b:h", longopts, NULL)) != -1 ) {
+  while ( (opt = getopt_long(argc, argv, "iof:p:t:x:y:b:kMGh", longopts, NULL)) != -1 ) {
     switch ( opt ) {
     case 'i':
       measure_input = 1;
@@ -231,6 +240,18 @@ int main(int argc, char *argv[])
     case 'b':
       border = atoi(optarg);
       break;
+    case 'k':
+      unit = 1.0e+3;
+      unit_name = "kbit/s";
+      break;
+    case 'M':
+      unit = 1.0e+6;
+      unit_name = "Mbit/s";
+      break;
+    case 'G':
+      unit = 1.0e+9;
+      unit_name = "Gbit/s";
+      break;
     case 'h':
       usage(0);
       break;
@@ -253,7 +274,7 @@ int main(int argc, char *argv[])
   sprintf(g_tmp, "%s.tmp", graphics_file);
 
   interface = argv[optind];
-  maxbandwidth = atof(argv[optind+1]) * 1.0e+6;
+  maxbandwidth = atof(argv[optind+1]) * unit;
 
   first = 1;
   lbin = 0; lbout = 0;
@@ -310,7 +331,7 @@ int main(int argc, char *argv[])
       ubar = fopen(t_tmp, "w");
       pngmaker = fopen(g_tmp, "w");
       if ( ubar ) {
-	fprintf(ubar, "Current bandwidth utilization %6.2f Mbit/s\n", bwmeasure/1.0e+6);
+	fprintf(ubar, "Current bandwidth utilization %6.2f %s\n", bwmeasure/unit, unit_name);
 	fclose(ubar);
 	rename(t_tmp, text_file);
       }
